@@ -1,7 +1,7 @@
 package App::CheckArchiveFilename;
 
 our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -58,7 +58,8 @@ sub check_archive_filename {
     }
 
     [200, "OK", \@res, {
-        'table.fields' => [qw/filename is_archive is_compressed/],
+        'table.fields' => [qw/filename is_archive is_compressed
+                             archive_name compressor_name compressor_suffix/],
     }];
 }
 
@@ -77,7 +78,7 @@ App::CheckArchiveFilename - Return information about archive & compressor types
 
 =head1 VERSION
 
-This document describes version 0.002 of App::CheckArchiveFilename (from Perl distribution App-CheckArchiveFilename), released on 2016-09-09.
+This document describes version 0.003 of App::CheckArchiveFilename (from Perl distribution App-CheckArchiveFilename), released on 2016-09-09.
 
 =head1 FUNCTIONS
 
